{% extends "base.html" %}

{% block content_title %}Following{% endblock %}

{% block content %}
  <ul>
    {% for person in user.following() %}
      <li><a href="{{ url_for('user_detail', username=person.username) }}">{{ person.username }}</a></li>
    {% endfor %}
  </ul>
  {% include "includes/pagination.html" %}
{% endblock %}
